
import json
import requests
import rrdtool


class Search(object):
    def __init__(self, **kwargs):
        self.base_url = kwargs['url']
        self.user = kwargs['user']
        self.password = kwargs['password']
        self.search = kwargs['search']

    def _url(self):
        raise NotImplementedError

    def _process(self, data):
        raise NotImplementedError

    def get(self):
        data = json.loads(requests.get(self._url(), verify=False).text)
        return self._process(data)


class GraphiteSearch(Search):
    def __init__(self, **kwargs):
        super(GraphiteSearch, self).__init__(**kwargs)

    def _url(self):
        params = ["from={}".format(self.start),
                  "until={}".format(self.end)]
        params += ["target={}".format(search) for search in self.search]
        url = '/render?format=json&{}'.format('&'.join(params))
        return self.base_url + url


class InfluxSearch(Search):
    def __init__(self, **kwargs):
        super(InfluxSearch, self).__init__(**kwargs)
        self.partition = kwargs['partition']

    def _url(self):
        params = ["q={}".format(search) for search in self.search]
        if self.user is not None:
            params += ["u={}".format(self.user), "p={}".format(self.password)]
        url = '/search?db={}&epoch=s&{}'.format(self.partition,
                                                '&'.join(params))
        return self.base_url + url


class PrometheusSearch(Search):
    def __init__(self, **kwargs):
        super(PrometheusSearch, self).__init__(**kwargs)

    def _url(self):
        params = []
        params += ["match[]={}".format(search) for search in self.search]
        if self.start is not None:
            params += ["start={}".format(self.start),
                       "end={}".format(self.end)]
        url = '/api/v1/series?' + '&'.join(params)
        return self.base_url + url

    def _process(self, response):
        print response


class RrdSearch(Search):
    def __init__(self, **kwargs):
        super(RrdSearch, self).__init__(**kwargs)

    def _url(self):
        return str(self.base_url.replace('file://', ''))

    def get(self):
        data_sources = set()
        info = rrdtool.info(self._url())
        for datum, real_value in info.items():
            if datum.startswith('ds'):
                value = datum.replace('ds[', '').split('].')
                # if value[0] not in data_source:
                #     data_source[value[0]] = {}
                # data_source[value[0]][value[1]] = real_value
                data_sources.add(value[0])
        return list(data_sources)



#!/usr/bin/env python

import json
import requests
import rrdtool
import pandas as pd
import numpy as np
import datetime

PROMETHEUS_REPLY = 'Prometheus API replied with error {}: {}'


class InstantQuery(object):
    def __init__(self, **kwargs):
        self.base_url = kwargs['url']
        self.user = kwargs['user']
        self.password = kwargs['password']
        self.queries = kwargs['queries']
        self.moment = kwargs['moment']
        self.verify = False

    def _process(self, data):
        raise NotImplementedError

    def _url(self):
        raise NotImplementedError

    def get(self):
        data = json.loads(requests.get(self._url(), verify=False).text)
        return self._process(data)

    def _http_get_params(self):
        return json.loads(requests.get(self._url(),
                                       params=self._params(),
                                       verify=self.verify).text)

    def _http_get_data(self):
        return json.loads(requests.get(self._url(),
                                       data=json.dumps(self._params()),
                                       verify=self.verify).text)


class GraphiteInstantQuery(InstantQuery):
    def __init__(self, **kwargs):
        super(GraphiteInstantQuery, self).__init__(**kwargs)

    def _url(self):
        params = ["from={}".format(self.start),
                  "until={}".format(self.end)]
        params += ["target={}".format(query) for query in self.queries]
        url = '/render?format=json&{}'.format('&'.join(params))
        return self.base_url + url


class InfluxInstantQuery(InstantQuery):
    def __init__(self, **kwargs):
        super(InfluxInstantQuery, self).__init__(**kwargs)
        self.partition = kwargs['partition']

    def _url(self):
        params = ["q={}".format(query) for query in self.queries]
        if self.user is not None:
            params += ["u={}".format(self.user), "p={}".format(self.password)]
        url = '/query?db={}&epoch=s&{}'.format(self.partition,
                                               '&'.join(params))
        return self.base_url + url


class PrometheusInstantQuery(InstantQuery):

    def __init__(self, **kwargs):
        super(PrometheusInstantQuery, self).__init__(**kwargs)

    def get(self):
        data = self._http_get_params()
        return self._process(data)

    def _params(self):
        return {
            "query": self.queries,
            "time": self.moment
        }

    def _url(self):
        url = '/api/v1/query'
        return self.base_url + url

    def _process(self, response):
        if response['status'] == 'error':
            raise Exception(PROMETHEUS_REPLY.format(response['errorType'],
                                                    response['error']))
        data = response['data']['result']
        for series in data:
            for values in [series['value']]:
                values[0] = pd.Timestamp(datetime.datetime.fromtimestamp(values[0]))
                values[1] = float(values[1])
        np_data = [('{}_{}'.format(series['metric']['__name__'],
                                   series['metric']['instance']),
                                   np.array([series['value']])) for series in data]
        series = []
        for query, serie in np_data:
            frame = pd.DataFrame(serie[:, 1],
                                 index=serie[:, 0],
                                 columns=[query])
            series.append(frame)
        if len(series) > 0:
            return pd.concat(series, axis=1, join='inner')
        else:
            return None


class RrdInstantQuery(InstantQuery):
    def __init__(self, **kwargs):
        super(RrdInstantQuery, self).__init__(**kwargs)
        self.url = kwargs['url']

    def get(self):
        data = json.loads(requests.get(self._url(), verify=False).text)
        return self._process(data)



#!/usr/bin/env python

import json
import requests
import pandas as pd
import numpy as np

PROMETHEUS_REPLY = 'Prometheus API replied with error {}: {}'


class InstantQuery(object):

    def __init__(self, **kwargs):
        self.base_url = kwargs['url']
        self.user = kwargs['user']
        self.password = kwargs['password']
        self.queries = kwargs['queries']
        self.moment = kwargs['moment']

    def _url(self):
        raise NotImplementedError

    def _process(self, data):
        raise NotImplementedError

    def get(self):
        data = json.loads(requests.get(self._url(), verify=False).text)
        return self._process(data)


class GraphiteInstantQuery(InstantQuery):
    def __init__(self, **kwargs):
        super(GraphiteInstantQuery, self).__init__(**kwargs)

    def _url(self):
        params = ["from={}".format(self.start),
                  "until={}".format(self.end)]
        params += ["target={}".format(query) for query in self.queries]
        url = '/render?format=json&{}'.format('&'.join(params))
        return self.base_url + url


class InfluxInstantQuery(InstantQuery):
    def __init__(self, **kwargs):
        super(InfluxInstantQuery, self).__init__(**kwargs)
        self.partition = kwargs['partition']

    def _url(self):
        params = ["q={}".format(query) for query in self.queries]
        if self.user is not None:
            params += ["u={}".format(self.user), "p={}".format(self.password)]
        url = '/query?db={}&epoch=s&{}'.format(self.partition, '&'.join(params))
        return self.base_url + url


class PrometheusInstantQuery(InstantQuery):
    def __init__(self, **kwargs):
        super(PrometheusInstantQuery, self).__init__(**kwargs)

    def _url(self):
        params = []
        params += ["query={}".format(query) for query in self.queries]
        params += ["time={}".format(self.moment)]
        url = '/api/v1/query?' + '&'.join(params)
        return self.base_url + url

    def _process(self, response):
        if response['status'] == 'error':
            raise Exception(PROMETHEUS_REPLY.format(response['errorType'],
                                                    response['error']))


class RangeQuery(object):

    def __init__(self, **kwargs):
        self.base_url = kwargs['url']
        self.user = kwargs['user']
        self.password = kwargs['password']
        self.queries = kwargs['queries']
        self.start = kwargs['start']
        self.end = kwargs['end']
        self.step = kwargs['step']

    def _url(self):
        raise NotImplementedError

    def _process(self, data):
        raise NotImplementedError

    def get(self):
        data = json.loads(requests.get(self._url(), verify=False).text)
        return self._process(data)


class GraphiteRangeQuery(RangeQuery):
    def __init__(self, **kwargs):
        super(GraphiteRangeQuery, self).__init__(**kwargs)

    def _url(self):
        params = ["target={}".format(query) for query in self.queries]
        params += ["from={}".format(self.start),
                   "until={}".format(self.end)]
        url = '/render?format=json&{}'.format('&'.join(params))
        return self.base_url + url

    def _process(self, data):
        np_data = [(series['query'],
                    np.array(series['datapoints'])) for series in data]
        series = [pd.DataFrame(series[:, 0],
                               index=series[:, 1],
                               columns=[query]) for query, series in np_data if series.any()]
        if len(series) > 0:
            return pd.concat(series, axis=1, join='inner')
        else:
            return None


class InfluxRangeQuery(RangeQuery):
    def __init__(self, **kwargs):
        super(InfluxRangeQuery, self).__init__(**kwargs)
        self.partition = kwargs['partition']

    def _url(self):
        params = ["q={}".format(query) for query in self.queries]
        if self.user is not None:
            params += ["u={}".format(self.user), "p={}".format(self.password)]
        url = '/query?db={}&epoch=s&{}'.format(self.partition, '&'.join(params))
        return self.base_url + url

    def _process(self, response):
        data = response['results'][0]['series']
        np_data = [(series['name'],
                    np.array(series['values'])) for series in data]
        series = []
        for query, serie in np_data:
            frame = pd.DataFrame(serie[:, 1],
                                 index=serie[:, 0],
                                 columns=[query])
            series.append(frame)
        if len(series) > 0:
            return pd.concat(series, axis=1, join='inner')
        else:
            return None


class PrometheusRangeQuery(RangeQuery):
    def __init__(self, **kwargs):
        super(PrometheusRangeQuery, self).__init__(**kwargs)

    def _url(self):
        params = ["query={}".format(query) for query in self.queries]
        params += ["start={}".format(self.start),
                   "end={}".format(self.end),
                   "step={}".format(self.step)]
        url = '/api/v1/query_range?{}'.format('&'.join(params))
        return self.base_url + url

    def _process(self, response):
        if response['status'] == 'error':
            raise Exception(PROMETHEUS_REPLY.format(response['errorType'],
                                                    response['error']))
        data = response['data']['result']
        np_data = [('{}_{}'.format(series['metric']['__name__'],
                                   series['metric']['instance']),
                                   np.array(series['values'])) for series in data]
        series = []
        for query, serie in np_data:
            frame = pd.DataFrame(serie[:, 1],
                                 index=serie[:, 0],
                                 columns=[query])
            series.append(frame)
        if len(series) > 0:
            return pd.concat(series, axis=1, join='inner')
        else:
            return None



#!/usr/bin/env python

import json
import requests
import rrdtool
import pandas as pd
import numpy as np
import datetime

PROMETHEUS_REPLY = 'Prometheus API replied with error {}: {}'


class RangeQuery(object):

    def __init__(self, **kwargs):
        self.base_url = kwargs['url']
        self.user = kwargs['user']
        self.password = kwargs['password']
        self.queries = kwargs['queries']
        self.start = kwargs['start']
        self.end = kwargs['end']
        self.step = kwargs['step']
        self.verify = False

    def _process(self, data):
        raise NotImplementedError

    def _url(self):
        raise NotImplementedError

    def _http_get_params(self):
        return json.loads(requests.get(self._url(),
                                       params=self._params(),
                                       verify=self.verify).text)

    def _http_get_data(self):
        return json.loads(requests.get(self._url(),
                                       data=json.dumps(self._params()),
                                       verify=self.verify).text)


class ElasticSearchRangeQuery(RangeQuery):

    def __init__(self, **kwargs):
        super(ElasticSearchRangeQuery, self).__init__(**kwargs)

    def get(self):
        data = self._http_get_data()
        return self._process(data)

    def _url(self):
        url = '/_search'
        return self.base_url + url

    def _params(self):
        return {
            'query': self.queries[0]
        }

    def _process(self, data):
        np_data = [(series['query'],
                    np.array(series['datapoints'])) for series in data]
        series = [pd.DataFrame(series[:, 0],
                               index=series[:, 1],
                               columns=[query]) for query, series in np_data if series.any()]
        if len(series) > 0:
            return pd.concat(series, axis=1, join='inner')
        else:
            return None


class GraphiteRangeQuery(RangeQuery):
    def __init__(self, **kwargs):
        super(GraphiteRangeQuery, self).__init__(**kwargs)

    def get(self):
        data = self._http_get_params()
        return self._process(data)

    def _params(self):
        return {
            'target': self.queries,
            'from': self.start,
            'until': self.end,
            'format': 'json'
        }

    def _url(self):
        url = '/render'
        return self.base_url + url

    def _process(self, data):
        np_data = [(series['query'],
                    np.array(series['datapoints'])) for series in data]
        series = [pd.DataFrame(series[:, 0],
                               index=series[:, 1],
                               columns=[query]) for query, series in np_data if series.any()]
        if len(series) > 0:
            return pd.concat(series, axis=1, join='inner')
        else:
            return None


class InfluxRangeQuery(RangeQuery):
    def __init__(self, **kwargs):
        super(InfluxRangeQuery, self).__init__(**kwargs)
        self.partition = kwargs['partition']

    def get(self):
        data = self._http_get_params()
        return self._process(data)

    def _params(self):
        params = {
            'db': self.partition,
            'epoch': 's',
            'q': self.queries[0]
        }
        if self.user is not None:
            params['u'] = self.user
            params['p'] = self.password
        return params

    def _url(self):
        url = '/query'
        return self.base_url + url

    def _process(self, response):
        data = response['results'][0]['series']
        np_data = [(series['name'],
                    np.array(series['values'])) for series in data]
        series = []
        for query, serie in np_data:
            frame = pd.DataFrame(serie[:, 1],
                                 index=serie[:, 0],
                                 columns=[query])
            series.append(frame)
        if len(series) > 0:
            return pd.concat(series, axis=1, join='inner')
        else:
            return None


class PrometheusRangeQuery(RangeQuery):
    def __init__(self, **kwargs):
        super(PrometheusRangeQuery, self).__init__(**kwargs)

    def get(self):
        data = self._http_get_params()
        return self._process(data)

    def _params(self):
        return {
            "query": self.queries,
            "start": self.start,
            "end": self.end,
            "step": self.step
        }

    def _url(self):
        url = '/api/v1/query_range'
        return self.base_url + url

    def _process(self, response):
        if response['status'] == 'error':
            raise Exception(PROMETHEUS_REPLY.format(response['errorType'],
                                                    response['error']))
        data = response['data']['result']
        for series in data:
            for values in series['values']:
                values[0] = pd.Timestamp(datetime.datetime.fromtimestamp(values[0]))
                values[1] = float(values[1])
        np_data = [('{}_{}'.format(series['metric']['__name__'],
                                   series['metric']['instance']),
                                   np.array(series['values'])) for series in data]
        series = []
        for query, serie in np_data:
            frame = pd.DataFrame(serie[:, 1],
                                 index=serie[:, 0],
                                 columns=[query])
            series.append(frame)
        if len(series) > 0:
            return pd.concat(series, axis=1, join='inner')
        else:
            return None


class RrdRangeQuery(RangeQuery):
    def __init__(self, **kwargs):
        super(RrdRangeQuery, self).__init__(**kwargs)
        self.url = kwargs['url']

    def get(self):
        result = rrdtool.fetch(self._url(), str(self.queries[0]))

        start, end, step = result[0]
        ds = result[1]
        rows = result[2]
        print start, end, step
        print ds
        print rows
#        return self._process(data)

    def _url(self):
        return str(self.base_url.replace('file://', ''))





class InstantAlarm(object):

    def __init__(self, **kwargs):
        self.alarm_operator = kwargs['alarm_operator']
        self.alarm_threshold = float(kwargs['alarm_threshold'])
        self.data_frame = kwargs['data_frame']
        self.series = kwargs['series']
        self.value = self._aggregate_series()

    def _aggregate_series(self):
        return float(self.data_frame[self.series].item())

    def evaluate(self):
        print "Question: {} {} {}?".format(self.alarm_threshold,
                                           self.alarm_operator,
                                           self.value)
        response = False
        if self.alarm_operator == 'gt':
            if self.alarm_threshold > self.value:
                response = True
        elif self.alarm_operator == 'gte':
            if self.alarm_threshold >= self.value:
                response = True
        elif self.alarm_operator == 'lt':
            if self.alarm_threshold < self.value:
                response = True
        elif self.alarm_operator == 'lte':
            if self.alarm_threshold <= self.value:
                response = True
        elif self.alarm_operator == 'eq':
            if self.alarm_threshold == self.value:
                response = True
        return response


class RangeAlarm(InstantAlarm):

    def __init__(self, **kwargs):
        self.alarm_operator = kwargs['alarm_operator']
        self.alarm_threshold = float(kwargs['alarm_threshold'])
        self.data_frame = kwargs['data_frame']
        self.aggregation = kwargs['aggregation']
        self.series = kwargs['series']
        self.value = self._aggregate_series()

    def _aggregate_series(self):
        if self.aggregation == 'avg':
            self.value = float(self.data_frame[self.series].mean())
        elif self.aggregation == 'min':
            self.value = float(self.data_frame[self.series].min())
        elif self.aggregation == 'max':
            self.value = float(self.data_frame[self.series].max())
        else:
            self.value = float(self.data_frame[self.series].sum())



#!/usr/bin/env python

import click
from libmetric.query_range import (InfluxRangeQuery, GraphiteRangeQuery,
                                   PrometheusRangeQuery, RrdRangeQuery)
from libmetric.query_instant import (InfluxInstantQuery, GraphiteInstantQuery,
                                     PrometheusInstantQuery, RrdInstantQuery)
from libmetric.search import (GraphiteSearch, PrometheusSearch, InfluxSearch,
                              RrdSearch)
from libmetric.alarm import RangeAlarm, InstantAlarm


@click.command()
@click.option('--engine', default='prometheus',
              help="Engine [prometheus, elasticsearch, influxdb]")
@click.option('--url', default=None,
              help="Server URL")
@click.option('--user', default=None,
              help="Authentication username")
@click.option('--password', default=None,
              help="Authentication password")
@click.option('--partition', default=None,
              help="Data partition")
@click.option('--query', default=None,
              help="Time-series query")
@click.option('--start', default=None,
              help="Time range start")
@click.option('--end', default=None,
              help="Time range end")
@click.option('--step', default=None,
              help="Query resolution step width")
def _range_metric(engine, url, user, password, partition, query,
                  start, end, step):
    data = {
        'queries': [query],
        'url': url,
        'user': user,
        'password': password,
        'partition': partition,
        'step': step,
        'start': start,
        'end': end
    }

    if engine == 'prometheus':
        query = PrometheusRangeQuery(**data)
    elif engine == 'influxdb':
        query = InfluxRangeQuery(**data)
    elif engine == 'graphite':
        query = GraphiteRangeQuery(**data)
    elif engine == 'rrd':
        query = RrdRangeQuery(**data)
    else:
        raise Exception("Unsupported engine {}.".format(engine))

    print query.get()


def range_metric():
    _range_metric(auto_envvar_prefix='LIBMETRIC')


@click.command()
@click.option('--engine', default='prometheus',
              help="Engine [prometheus, elasticsearch, influxdb]")
@click.option('--url', default=None,
              help="Server URL")
@click.option('--user', default=None,
              help="Authentication username")
@click.option('--password', default=None,
              help="Authentication password")
@click.option('--partition', default=None,
              help="Data partition")
@click.option('--query', default=None,
              help="Time-series query")
@click.option('--start', default=None,
              help="Time range start")
@click.option('--end', default=None,
              help="Time range end")
@click.option('--step', default=None,
              help="Query resolution step width")
@click.option('--alarm-threshold', default=None,
              help="Threshold value for the alarm")
@click.option('--alarm-operator', default=None,
              help="Arithmetic operator for alarm evaluation")
@click.option('--alarm-series', default=None,
              help="Series to perform alarm against")
@click.option('--aggregation', default=None,
              help="Aggregation function for the given time-series")
def _range_alarm(engine, url, user, password, partition, query, start, end,
                 step, alarm_operator, alarm_threshold, alarm_series,
                 aggregation):
    data = {
        'queries': [query],
        'url': url,
        'user': user,
        'password': password,
        'partition': partition,
        'step': step,
        'start': start,
        'end': end
    }

    if engine == 'prometheus':
        query = PrometheusRangeQuery(**data)
    elif engine == 'influxdb':
        query = InfluxRangeQuery(**data)
    elif engine == 'graphite':
        query = GraphiteRangeQuery(**data)
    elif engine == 'rrd':
        query = RrdRangeQuery(**data)
    else:
        raise Exception("Unsupported engine {}.".format(engine))

    data_frame = query.get()
    alarm = {
        'alarm_operator': alarm_operator,
        'alarm_threshold': alarm_threshold,
        'aggregation': aggregation,
        'series': alarm_series,
        'data_frame': data_frame
    }
    result = RangeAlarm(**alarm).evaluate()
    print "Response: {}".format(result)


def range_alarm():
    _range_alarm(auto_envvar_prefix='LIBMETRIC')


@click.command()
@click.option('--engine', default='prometheus',
              help="Engine [prometheus, elasticsearch, influxdb]")
@click.option('--url', default=None,
              help="Server URL")
@click.option('--user', default=None,
              help="Authentication username")
@click.option('--password', default=None,
              help="Authentication password")
@click.option('--partition', default=None,
              help="Data partition")
@click.option('--query', default=None,
              help="Time-series query")
@click.option('--moment', default=None,
              help="Moment in time")
def _instant_metric(engine, url, user, password, partition, query, moment):
    data = {
        'queries': [query],
        'url': url,
        'user': user,
        'password': password,
        'partition': partition,
        'moment': moment,
    }

    if engine == 'prometheus':
        query = PrometheusInstantQuery(**data)
    elif engine == 'influxdb':
        query = InfluxInstantQuery(**data)
    elif engine == 'graphite':
        query = GraphiteInstantQuery(**data)
    elif engine == 'rrd':
        query = RrdInstantQuery(**data)
    else:
        raise Exception("Unsupported engine {}.".format(engine))

    print query.get()


def instant_metric():
    _instant_metric(auto_envvar_prefix='LIBMETRIC')


@click.command()
@click.option('--engine', default='prometheus',
              help="Engine [prometheus, elasticsearch, influxdb]")
@click.option('--url', default=None,
              help="Server URL")
@click.option('--user', default=None,
              help="Authentication username")
@click.option('--password', default=None,
              help="Authentication password")
@click.option('--partition', default=None,
              help="Data partition")
@click.option('--query', default=None,
              help="Time-series query")
@click.option('--moment', default=None,
              help="Moment in time")
@click.option('--alarm-threshold', default=None,
              help="Threshold value for the alarm")
@click.option('--alarm-operator', default=None,
              help="Arithmetic operator for alarm evaluation")
@click.option('--alarm-series', default=None,
              help="Series to perform alarm against")
def _instant_alarm(engine, url, user, password, partition, query, moment,
                   alarm_operator, alarm_threshold, alarm_series):
    data = {
        'queries': [query],
        'url': url,
        'user': user,
        'password': password,
        'partition': partition,
        'moment': moment,
    }

    if engine == 'prometheus':
        query = PrometheusInstantQuery(**data)
    elif engine == 'influxdb':
        query = InfluxInstantQuery(**data)
    elif engine == 'graphite':
        query = GraphiteInstantQuery(**data)
    elif engine == 'rrd':
        query = RrdInstantQuery(**data)
    else:
        raise Exception("Unsupported engine {}.".format(engine))

    data_frame = query.get()
    alarm = {
        'alarm_operator': alarm_operator,
        'alarm_threshold': alarm_threshold,
        'series': alarm_series,
        'data_frame': data_frame
    }
    result = InstantAlarm(**alarm).evaluate()
    print "Response: {}".format(result)


def instant_alarm():
    _instant_alarm(auto_envvar_prefix='LIBMETRIC')


@click.command()
@click.option('--engine', default='prometheus',
              help="Engine [prometheus, elasticsearch, influxdb]")
@click.option('--url', default=None,
              help="Server URL")
@click.option('--user', default=None,
              help="Authentication username")
@click.option('--password', default=None,
              help="Authentication password")
@click.option('--partition', default=None,
              help="Data partition")
@click.option('--search', default=None,
              help="Search time-series")
@click.option('--start', default=None,
              help="Time range start")
@click.option('--end', default=None,
              help="Time range end")
def _search_metrics(engine, url, user, password, partition, search,
                    start, end):
    data = {
        'search': [search],
        'url': url,
        'user': user,
        'password': password,
        'partition': partition,
        'start': start,
        'end': end
    }

    if engine == 'prometheus':
        search = PrometheusSearch(**data)
    elif engine == 'influxdb':
        search = InfluxSearch(**data)
    elif engine == 'graphite':
        search = GraphiteSearch(**data)
    elif engine == 'rrd':
        search = RrdSearch(**data)
    else:
        raise Exception("Unsupported engine {}".format(engine))

    print search.get()


def search_metrics():
    _search_metrics(auto_envvar_prefix='LIBMETRIC')
